@@ -1,6 +1,4 @@
 # get_available_radar()---------------------------------------------------------
-context("Available radar imagery")
-
 test_that("get_available_radar error handling works", {
   skip_on_cran()
   expect_error(expect_warning(get_available_radar(radar_id = "abc")))
@@ -26,8 +24,6 @@ test_that("get_available_radar functions properly", {
 })
 
 # get_radar_imagery()-----------------------------------------------------------
-context("Fetching radar imagery")
-
 test_that("Error handling works", {
   skip_on_cran()
   expect_error(expect_warning(get_radar_imagery(product_id = "abc")))
